@@ -263,10 +263,17 @@ def _int2float(a):
         return type(a)([_int2float(v) for v in a])
     elif isinstance(a, dict):
         return type(a)({k : _int2float(v) for k,v in a.items()})
-    if (is_series(a) or is_df(a) or is_array(a)) and a.dtype in _dtype_ints:
+    if (is_series(a) or is_array(a)) and a.dtype in _dtype_ints:
         return a.astype(float)
-    else:
-        return a
+    if is_df(a):
+        if hasattr(a, 'dtype'):
+            if a.dtype in _dtype_ints:
+                return a.astype(float)
+        else:
+            ints = {k: float for k,v in dict(a.dtypes).items() if v in _dtype_ints}
+            if len(ints):
+                return a.astype(ints)
+    return a
     
 
 def _values(a):
